==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Gefälschter User Agent</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Domäne:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Agent:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% und %Subplatform% werden durch das Fenstersystem und das Betriebssystem ersetzt.
%Security% wird durch U ersetzt, wenn SSL aktiviert ist, ansonsten durch N.
%Locale% wird durch den Namen des aktuellen Einstellungssatzes für Gebietsschemaparameter ersetzt.
%WebKitVersion% wird durch die WebKit-Version ersetzt.
%AppVersion% wird durch die Version der Anwendung ersetzt.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="60"/>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="61"/>
        <source>Agent</source>
        <translation>Agent</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="62"/>
        <source>Identification string</source>
        <translation>Identifikations Nummer</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="101"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Erlaubt die Einstellung gefälschter User Agents für verschiedene Websites.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Bearbeiten...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Änderungen werden sofort übernommen</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Gefälschter User Agent</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Domäne:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Agent:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% und %Subplatform% werden durch das Fenstersystem und das Betriebssystem ersetzt.
%Security% wird durch U ersetzt, wenn SSL aktiviert ist, ansonsten durch N.
%Locale% wird durch den Namen des aktuellen Einstellungssatzes für Gebietsschemaparameter ersetzt.
%WebKitVersion% wird durch die WebKit-Version ersetzt.
%AppVersion% wird durch die Version der Anwendung ersetzt.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="70"/>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="71"/>
        <source>Agent</source>
        <translation>Agent</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="72"/>
        <source>Identification string</source>
        <translation>Identifikations Nummer</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="116"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Erlaubt die Einstellung gefälschter User Agents für verschiedene Websites.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Bearbeiten...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Änderungen werden sofort übernommen</translation>
    </message>
</context>
<context>
    <name>poshukufuasettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>FUA settings</source>
        <translation>FUA-Einstellungen</translation>
    </message>
</context>
</TS>
